@@ -1,8 +1,8 @@
 use anyhow::Result;
 use console::Style;
+use indexmap::IndexMap;
 use similar::ChangeTag;
 use similar::TextDiff;
-use std::collections::HashMap;
 use std::fmt::Display;
 use std::fs;
 use std::panic::catch_unwind;
@@ -53,8 +53,8 @@ pub fn run_specs(
   directory_path: &Path,
   parse_spec_options: &ParseSpecOptions,
   run_spec_options: &RunSpecsOptions,
-  format_text: impl Fn(&Path, &str, &HashMap<String, String>) -> Result<String>,
-  get_trace_json: impl Fn(&Path, &str, &HashMap<String, String>) -> String,
+  format_text: impl Fn(&Path, &str, &IndexMap<String, String>) -> Result<String>,
+  get_trace_json: impl Fn(&Path, &str, &IndexMap<String, String>) -> String,
 ) {
   #[cfg(not(debug_assertions))]
   assert_not_fix_failures(run_spec_options);
@@ -71,14 +71,7 @@ pub fn run_specs(
     let format = |file_text: &str| {
       let result = catch_unwind(AssertUnwindSafe(|| format_text(&file_path_buf, file_text, &spec.config)));
       let result = result.unwrap_or_else(|err| panic!("Panic in spec '{}' in {}.\n\n{:?}", spec.message, file_path.display(), err));
-      result.unwrap_or_else(|err| {
-        panic!(
-          "Could not parse spec '{}' in {}. Message: {}",
-          spec.message,
-          file_path.display(),
-          err.to_string()
-        )
-      })
+      result.unwrap_or_else(|err| panic!("Could not parse spec '{}' in {}. Message: {}", spec.message, file_path.display(), err,))
     };
 
     if spec.is_trace {
